import django_filters
from rest_framework import filters, viewsets

from inventory.models import (
    InventoryObject,
    IPv4Network,
    RacksUser,
)

from inventory.serializers import UserSerializer
from inventory.serializers import InventoryObjectSerializer
from inventory.serializers import IPv4NetworkSerializer


class UserViewSet(viewsets.ModelViewSet):
    queryset = RacksUser.objects.all()
    serializer_class = UserSerializer
    filter_backends = (filters.DjangoFilterBackend, filters.OrderingFilter)
    filter_fields = ('id', 'username', 'email', 'inventory_objects')
    ordering_fields = ('id',)
    ordering = ('username')


class InventoryObjectFilter(filters.FilterSet):
    location__fact = django_filters.CharFilter(name='facter_location__fact')

    class Meta:
        model = InventoryObject
        fields = {
            'name',
            'responsible',
            'location__fact',
            'type__name'
        }


class InventoryObjectViewSet(viewsets.ModelViewSet):
    queryset = (InventoryObject.objects.all()
                .order_by('-created')
                .select_related('facter_location', 'facter_location__location'))
    serializer_class = InventoryObjectSerializer
    filter_backends = (filters.DjangoFilterBackend, filters.OrderingFilter)
    filter_class = InventoryObjectFilter
    ordering_fields = ('id',)


class IPv4NetworkViewSet(viewsets.ModelViewSet):
    queryset = IPv4Network.objects.all().order_by('-created')
    serializer_class = IPv4NetworkSerializer
